@@ -1,7 +1,7 @@
 use strictures 1;
 package Mojito::Page::Render;
 {
-  $Mojito::Page::Render::VERSION = '0.21';
+  $Mojito::Page::Render::VERSION = '0.22';
 }
 use 5.010;
 use Moo;
@@ -170,6 +170,8 @@ Given some content and its format, let's convert it to HTML.
 sub format_for_web {
     my ( $self, $content, $from_language ) = @_;
 
+    # smartmatch throws warnings on 5.18.0+, suppress them
+    no if $] >= 5.018000, warnings => qw(experimental::smartmatch); 
     my $formatted_content = $content;
     given ($from_language) {
         when (/^HTML$/i) {
