@@ -1,7 +1,7 @@
 use strictures 1;
 package Mojito::Role::DB::Mongo;
 {
-  $Mojito::Role::DB::Mongo::VERSION = '0.21';
+  $Mojito::Role::DB::Mongo::VERSION = '0.22';
 }
 use Moo::Role;
 use MongoDB;
@@ -53,7 +53,7 @@ sub _build_db  {
 #    warn $trace->as_string;
     my $self = shift;
     my $db_name = $self->db_name;
-    return $self->conn->${db_name};
+    return $self->conn->get_database($db_name);
 }
 sub _build_collection  {
     my $self = shift;
@@ -63,7 +63,7 @@ sub _build_collection  {
     if (not defined $self->db) {
         $self->clear_db;
     }
-    $self->db->${collection_name};
+    $self->db->get_collection($collection_name);
 }
 
-1;
\ No newline at end of file
+1;
